@@ -5,13 +5,12 @@
 // STDERR:
 Gio = imports.gi.Gio;
 sqlite = imports.sqlite;
+JSON = imports.JSON;
 
-try
-{
-	Gio.file_new_for_path("/tmp/.seed_test.db")["delete"]();
+try{
+    Gio.file_new_for_path("/tmp/.seed_test.db")["delete"]();
 }
-catch(e)
-{
+catch(e){
 }
 
 d = new sqlite.Database("/tmp/.seed_test.db");
@@ -21,6 +20,8 @@ d.exec("insert into t1 (data,num) values ('This is sample data',3);");
 d.exec("insert into t1 (data,num) values ('More sample data',6);");
 d.exec("insert into t1 (data,num) values ('And a little more',9);");
 
-d.exec("select * from t1", function(results){Seed.print(JSON.stringify(results));});
+d.exec("select * from t1", function(results){
+    print(JSON.stringify(results));
+});
 
 d.close();
